import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.util.List;

/**
 * Class where the leves and world desing are implemented
 * 
 * @Alberto Milan
 * @v1.0
 */
public class SnowWorld  extends World
{
    private int currLv;
    private int score;
    private int lifes;

    /**
     * Constructor for objects of class SnowWorld.
     * 
     */
    public SnowWorld()
     {     
       super(48, 31, 20); 
       Greenfoot.setSpeed(40);
       resetData();
       main();
    }
    /**
     * Method for discount lifes from the player
     * @return True if life is zero, false isn't
     */
    public boolean discountLife()
    {
        if(lifes > 0)
            lifes--;
        else
            return false;
        return true;
    }
    
    /**
     * Method that increment the points in game
     * @param val amount to rise
     */
    public void raiseScore(int val)
    {
        score += val;
    }
    /**
     * Method that increment life one by one
     */
    public void raiseLifes()
    {
        lifes++;   
    }
    /**
     * @return the current lifes
     */
    public int getLifes()
    {
        return lifes;
    }
    /**
     * @return the current score
     */
    public int getScore()
    {
        return score;
    }
    /**
     * @return the current level
     */
    public int getCurrLv()
    {
        return currLv;
    }
    /**
     * Method that restore the level at 1, lifes to 3, and score to 0
     */
    public void resetData()
    {
        currLv = 1;
        lifes = 3;
        score = 0;
    }
    /**
     * Method to change the level on game
     * @param lv to put
     */
    public void setLv(int lv)
    {
        currLv = lv;
    }
    /**
     * Method that draw the main screen 
     */
    public void main()
    {
        removeObjects(getObjects(null));
        setBackground("menu.png");
        Play b1 = new Play(this);
        addObject(b1,23,26);
        
        Help b2 = new Help(this);
        addObject(b2,40,26);
        
        About b3 = new About(this);
        addObject(b3,5,26);
    }
    /**
     * Method that starts the game
     */
    public void play()
    {
        setBackground("snow_map.png");
        Greenfoot.playSound("Freeze.wav");
        dibujaLv1();
    }
    /**
     * Method that draw the help screen
     */
    public void help()
    {
        removeObjects(getObjects(null));
        setBackground("help_menu.png");        
        Back b2 = new Back(this);
        addObject(b2,44,26);
    }
    /**
     * Method that draw the about game screen
     */
    public void about()
    {
        removeObjects(getObjects(null));
        setBackground("about_menu.png");
        
        Back b2 = new Back(this);
        addObject(b2,5,26);
    }
    /**
     * Method to remove all objects on scenario and re-paints the main screen
     */
    public void backMain()
    {
        removeObjects(getObjects(null));
        main();
    }
    /**
     * Method to create a obstacles horizontal line 
     * @param type of obstacle, 0=ice cube, 1=rock, 2=pine
     * @param n number of obstacles
     * @param x coordinate on x
     * @param y coordinate on y
     */
    public void addLineH(int type, int n, int x, int y)
    {
        switch(type){
            case 0 :    for(int i=0; i < n ; i++){
                            addObject(new IceCube(),x+i*3,y);
                        }
                        break;
            case 1 :    for(int i=0; i < n ; i++){
                            addObject(new Rock(),x+i*3,y);
                        }
                        break;
            case 2 :    for(int i=0; i < n ; i++){
                            addObject(new Pine(),x+i*3,y);
                        }
                        break;
                    }      
    }
        /**
     * Method to create a obstacles vertical line 
     * @param type of obstacle, 0=ice cube, 1=rock, 2=pine
     * @param n number of obstacles
     * @param x coordinate on x
     * @param y coordinate on y
     */
    public void addLineV(int type, int n, int x, int y)
    {
        switch(type){
            case 0 :    for(int i=0; i < n ; i++){
                            addObject(new IceCube(),x,y-i*3);
                        }
                        break;
            case 1 :    for(int i=0; i < n ; i++){
                            addObject(new Rock(),x,y-i*3);
                        }
                        break;
            case 2 :    for(int i=0; i < n ; i++){
                            addObject(new Pine(),x,y+i*3);
                        }
                        break;
                    }
    }
    /**
     * Method that create all objects of level 1
     */
    public void dibujaLv1()
    {   
        int i;
        setBackground("snow_map.png");
        if(getObjects(null) != null){
            removeObjects(getObjects(null));
            Greenfoot.start();
        }
        addObject(new Lock(), 22,2);
        addObject(new Female(),19,29);
        addObject(new Male(),25,29);
        addObject(new IceCube(),22,29); 
        addLineH(0,13,4,26);
        addObject(new IceCube(),22,23);
        addLineH(0,2,1,20);
        addLineH(0,2,40,20);
        for(i=0; i < 5 ; i++)
            addObject(new IceCube(),10+i*6,20);
        addLineV(0,3,22,17);
        addLineH(0,5,4,14);
        addLineH(0,5,28,14);
        addLineH(0,2,1,8);
        addLineH(0,3,22,8);
        addObject(new IceCube(),10,8);
        addObject(new IceCube(),16,8);
        addObject(new IceCube(),34,8);
        addObject(new IceCube(),40,8);
        addLineH(0,3,4,5);
        addLineH(0,3,16,5);
        addLineH(0,3,28,5);
        addLineH(0,2,40,5);
        addObject(new SpiderWeb(),7,11);
        addObject(new SpiderWeb(),37,17);
        addObject(new SpiderWeb(),37,5);
        addObject(new Spider(),4,2);
        addObject(new Spider(),31,8);

        addObject(new InfoScreen(),46,15);
        addObject(new Lifes(), 46,11);
        addObject(new Score(), 46,17);
        addObject(new Lv(), 46,4);
        addObject(new Time(),46,25);
        
    }
    /**
     * Method that create all objects of level 2
     */
    
    public void dibujaLv2()
    {
        int i;
        currLv=2;

        setBackground("snow_map.png");
        Greenfoot.start();//Re Starts the game on new Lv 
        removeObjects(getObjects(null)); // Clean all old objects from the last Lv
        addObject(new Lock(currLv), 22,2);
        addObject(new Female(),19,29); // Draw penguins on start position
        addObject(new Male(),25,29);  //Draw the Lv
        
        addObject(new IceCube(),16,29);
        addObject(new IceCube(),22,29);
        for(i=0; i < 3 ; i++)
            addObject(new IceCube(),4+i*6,26);
        addLineH(0,3,22,26);
        addObject(new IceCube(),34,26);
        addLineH(0,2,40,26);
        addObject(new IceCube(),10,23);
        addLineV(0,2,22,23);
        addObject(new IceCube(),22,17);
        addLineH(0,2,1,20);
        addLineH(0,3,10,20);
        addLineH(0,5,28,20);
        addLineH(0,3,4,14);
        addLineH(0,5,16,14);
        addLineV(0,2,34,14);
        addLineH(0,2,40,14);
        addObject(new IceCube(),22,11);
        addObject(new IceCube(),22,8);
        addLineV(0,2,4,8);
        addLineV(0,3,10,11);
        addLineV(0,2,16,8);
        addLineH(0,5,28,8);
        addLineH(0,4,19,5);
        addObject(new IceCube(),34,5);
        addObject(new IceCube(),40,5);
        addObject(new SpiderWeb(),1,23);
        addObject(new SpiderWeb(),16,23);
        addObject(new SpiderWeb(),37,23);
        addObject(new SpiderWeb(),7,17);
        addObject(new SpiderWeb(),25,17);
        addObject(new SpiderWeb(),1,11);
        addObject(new SpiderWeb(),19,11);
        addObject(new SpiderWeb(),43,11);
        addObject(new Spider(),4,2);
        addObject(new Spider(),25,23);
        addObject(new Spider(),10,17);
        addObject(new Spider(),43,5);
        addObject(new InfoScreen(),46,15);
        addObject(new Lifes(), 46,11);
        addObject(new Score(), 46,17);
        addObject(new Lv(), 46,4);
        addObject(new Time(),46,25);        
        
    }

    /**
     * Method that create all objects of level 3
     */
    public void dibujaLv3()
    {
        int i;
        currLv=3;
        setBackground("snow_map.png");
        Greenfoot.start();//Re Starts the game on new Lv 
        removeObjects(getObjects(null)); // Clean all old objects from the last Lv
        addObject(new Lock(currLv), 22,2);
        addObject(new Female(),19,29); // Draw penguins on start position
        addObject(new Male(),25,29);  //Draw the Lv
        
        addObject(new IceCube(),16,29);
        addObject(new IceCube(),22,29);
        addLineV(0,4,4,29);
        addLineV(0,4,10,26);
        addLineV(0,4,16,29);
        addLineV(0,3,22,29);
        addObject(new IceCube(),28,26);
        addLineV(0,2,34,26);
        addLineV(0,2,40,29);
        addLineH(0,3,22,20);
        addLineH(0,3,34,20);
        addLineH(0,6,4,14);
        addLineH(0,3,28,14);
        addLineH(0,2,40,14);
        addLineV(0,3,4,11);
        addLineV(0,3,10,8);
        addLineV(0,3,16,11);
        addLineV(0,2,28,8);
        addLineV(0,3,34,11);
        addLineV(0,2,40,8);
        addLineV(0,5,22,17);
        addObject(new IceCube(),43,5);
        for(i=0; i < 3; i++)
            addObject(new SpiderWeb(),1,5+i*3);
        addObject(new SpiderWeb(),1,23);
        addObject(new SpiderWeb(),7,26);
        addObject(new SpiderWeb(),19,23);
        addObject(new SpiderWeb(),25,23);
        addObject(new SpiderWeb(),40,23);
        addObject(new SpiderWeb(),4,17);
        addObject(new SpiderWeb(),13,17);
        addObject(new SpiderWeb(),31,17);
        addObject(new SpiderWeb(),25,11);
        addObject(new SpiderWeb(),43,11);
        addObject(new SpiderWeb(),7,8);
        addObject(new SpiderWeb(),19,8);
        addObject(new SpiderWeb(),13,2);
        addObject(new Spider(),4,2);
        addObject(new Spider(),25,23);
        addObject(new Spider(),7,17);
        addObject(new Spider(),43,2);
        addObject(new Spider(),43,23);
        addObject(new InfoScreen(),46,15);
        addObject(new Lifes(), 46,11);
        addObject(new Score(), 46,17);
        addObject(new Lv(), 46,4);
        addObject(new Time(),46,25);
    }

    /**
     * Method that create all objects of level 4
     */
    public void dibujaLv4()
    { 
        int i;
        currLv=4;

        setBackground("cave_map.png");
        Greenfoot.start();//Re Starts the game on new Lv 
        removeObjects(getObjects(null)); // Clean all old objects from the last Lv
        addObject(new Lock(currLv), 22,2);
        addObject(new Female(),19,29); // Draw penguins on start position
        addObject(new Male(),25,29);  //Draw the Lv
        
        addLineV(1,3,22,29);
        addLineV(1,2,28,29);
        addLineH(1,6,1,26);
        addLineV(1,2,34,26);
        addObject(new Rock(),40,26);
        addObject(new Rock(),4,20);
        addObject(new Rock(),10,20);
        addLineH(1,3,16,20);
        addLineH(1,3,28,20);
        addLineH(1,2,40,20);
        addObject(new Rock(),22,17);
        addObject(new Rock(),28,17);
        addLineH(1,5,4,14);
        addLineH(1,3,22,14);
        addLineH(1,3,34,14);
        addObject(new Rock(),22,11);
        addLineH(1,2,1,8);
        for(i=0; i < 4; i++)
            addObject(new Rock(),10+i*6,8);
        addLineV(1,3,34,11);
        addLineV(1,3,40,8);
        addLineH(1,3,4,5);
        addLineH(1,5,16,5);
        addObject(new SpiderWeb(),13,17);
        addObject(new SpiderWeb(),28,23);
        addObject(new SpiderWeb(),43,23);
        addObject(new SpiderWeb(),37,17);
        addObject(new SpiderWeb(),25,11);
        addObject(new SpiderWeb(),43,11);
        addObject(new Spider(),4,2);
        addObject(new Spider(),25,23);
        addObject(new Spider(),7,17);
        addObject(new Spider(),43,2);
        
        addObject(new InfoScreen(),46,15);
        addObject(new Lifes(), 46,11);
        addObject(new Score(), 46,17);
        addObject(new Lv(), 46,4);
        addObject(new Time(),46,25);
        
        
    }
    /**
     * Method that create all objects of level 5
     */
    public void dibujaLv5()
    {
        int i;
        currLv=5;

        setBackground("cave_map.png");
        Greenfoot.start();//Re Starts the game on new Lv 
        removeObjects(getObjects(null)); // Clean all old objects from the last Lv
        addObject(new Lock(currLv), 22,2);
        addObject(new Female(),19,29); // Draw penguins on start position
        addObject(new Male(),25,29);  //Draw the Lv
        
        addLineV(1,2,4,29);
        addLineV(1,2,10,26);
        addLineH(1,3,4,20);
        addObject(new Rock(),4,17);
        addLineH(1,2,1,14);
        addObject(new Rock(),16,26);
        addLineV(1,3,22,29);
        addLineH(1,3,28,26);
        addLineH(1,2,40,26);
        addLineH(1,5,16,20);
        addLineH(1,3,33,20);
        addLineH(1,3,10,14);
        addLineH(1,3,28,14);
        addLineH(1,2,40,14);
        addLineV(1,3,22,17);
        addObject(new Rock(),4,8);
        addLineH(1,2,1,5);
        addLineV(1,3,10,11);
        addLineV(1,3,16,8);
        addLineH(1,3,22,8);
        addLineH(1,3,34,8);
        for(i=0; i<4; i++)
            addObject(new Rock(),22+i*6,5);
        addObject(new SpiderWeb(),4,23);
        addObject(new SpiderWeb(),19,23);
        addObject(new SpiderWeb(),25,23);
        addObject(new SpiderWeb(),43,23);
        addObject(new SpiderWeb(),30,19);
        addObject(new SpiderWeb(),13,17);
        addObject(new SpiderWeb(),25,17);
        addObject(new SpiderWeb(),30,17);
        addObject(new SpiderWeb(),36,17);
        addObject(new SpiderWeb(),1,11);
        addObject(new SpiderWeb(),19,11);
        addObject(new SpiderWeb(),43,11);
        addObject(new Spider(),4,2);
        addObject(new Spider(),25,23);
        addObject(new Spider(),7,17);
        addObject(new Spider(),43,2);
        addObject(new Spider(),43,23);
        
        addObject(new InfoScreen(),46,15);
        addObject(new Lifes(), 46,11);
        addObject(new Score(), 46,17);
        addObject(new Lv(), 46,4);
        addObject(new Time(),46,25);
    }
    /**
     * Method that create all objects of level 6
     */
    public void dibujaLv6()
    {
        int i;
        currLv=6;

        setBackground("cave_map.png");
        Greenfoot.start();//Re Starts the game on new Lv 
        removeObjects(getObjects(null)); // Clean all old objects from the last Lv
        addObject(new Lock(currLv), 22,2);
        addObject(new Female(),19,29); // Draw penguins on start position
        addObject(new Male(),25,29);  //Draw the Lv
        
        addLineV(1,6,4,29);
        addLineV(1,6,10,26);
        addLineV(1,6,16,29);
        addLineV(1,7,22,29);
        addLineH(1,7,4,5);
        addLineH(1,7,4,8);//
        addLineH(1,2,25,26);
        addLineH(1,3,34,26);
        addLineH(1,3,28,20);
        addLineH(1,2,40,20);
        addLineH(1,2,25,14);
        addLineH(1,3,34,14);
        addLineH(1,6,28,5);
        addLineH(1,6,40,5);
        for(i=0; i<3; i++)
            addObject(new Rock(),28+i*6,5);
        addObject(new SpiderWeb(),1,14);
        addObject(new SpiderWeb(),4,11);
        addObject(new SpiderWeb(),7,26);
        addObject(new SpiderWeb(),10,29);
        addObject(new SpiderWeb(),10,2);
        addObject(new SpiderWeb(),13,14);
        addObject(new SpiderWeb(),19,14);
        addObject(new SpiderWeb(),25,11);
        addObject(new SpiderWeb(),25,23);
        for(i=0; i<3; i++)
            addObject(new SpiderWeb(),31+i*6,17);
        addObject(new SpiderWeb(),37,29);
        addObject(new SpiderWeb(),43,23);
        addObject(new Spider(),4,2);
        addObject(new Spider(),37,2);
        addObject(new Spider(),25,17);
        addObject(new Spider(),34,17);
        addObject(new Spider(),43,14);
        addObject(new Spider(),7,14);
        addObject(new Spider(),13,11);
            
        addObject(new InfoScreen(),46,15);
        addObject(new Lifes(), 46,11);
        addObject(new Score(), 46,17);
        addObject(new Lv(), 46,4);
        addObject(new Time(),46,25);
    }
    /**
     * Method that create all objects of level 7
     */
    public void dibujaLv7()
    {
        int i;
        currLv=7;

        setBackground("field_map.png");
        Greenfoot.start();//Re Starts the game on new Lv 
        removeObjects(getObjects(null)); // Clean all old objects from the last Lv
        addObject(new Lock(currLv), 22,2);
        addObject(new Female(),19,29); // Draw penguins on start position
        addObject(new Male(),25,29);  //Draw the Lv
        
        addLineH(2,2,1,26);
        addObject(new Pine(),10,26);
        addLineH(2,2,16,26);
        addLineH(2,5,4,20);
        addLineH(2,2,1,14);
        addLineH(2,2,16,14);
        addLineH(2,2,1,5);
        addObject(new Pine(),10,5);
        addObject(new Pine(),16,5);
        addLineH(2,5,4,8);
        addLineV(2,2,10,11);
        addLineV(2,9,22,5);
        addLineV(2,6,28,14);
        addLineV(2,6,34,11);
        addLineV(2,6,40,14);
        addLineH(2,6,28,5);
        addLineH(2,6,28,8);
        addObject(new SpiderWeb(),1,17);
        addObject(new SpiderWeb(),13,17);
        addObject(new SpiderWeb(),31,26);
        addObject(new SpiderWeb(),34,29);
        addObject(new SpiderWeb(),25,14);
        addObject(new SpiderWeb(),37,14);
        addObject(new SpiderWeb(),43,14);
        addObject(new SpiderWeb(),19,11);
        addObject(new SpiderWeb(),28,11);
        addObject(new SpiderWeb(),34,2);
        addObject(new Spider(),4,2);
        addObject(new Spider(),37,2);
        addObject(new Spider(),25,17);
        addObject(new Spider(),31,17);
        addObject(new Bird(),43,14);
        
        addObject(new InfoScreen(),46,15);
        addObject(new Lifes(), 46,11);
        addObject(new Score(), 46,17);
        addObject(new Lv(), 46,4);
        addObject(new Time(),46,25);
    }
    /**
     * Method that create all objects of level 8
     */
    public void dibujaLv8()
    {
        int i;
        currLv=8;

        setBackground("field_map.png");
        Greenfoot.start();//Re Starts the game on new Lv 
        removeObjects(getObjects(null)); // Clean all old objects from the last Lv
        addObject(new Lock(currLv), 22,2);
        addObject(new Female(),19,29); // Draw penguins on start position
        addObject(new Male(),25,29);  //Draw the Lv
        
        addLineH(2,2,40,2);
        addLineH(2,3,4,5);
        addLineH(2,2,16,5);
        addLineV(2,9,22,5);
        for(i=0; i<3; i++)
            addObject(new Pine(),4+i*6,8);
        for(i=0; i<3; i++)
            addObject(new Pine(),28+i*6,5);
        addLineH(2,3,28,8);
        addObject(new Pine(),40,8);
        addLineH(2,2,1,14);
        addLineH(2,3,8,14);
        addLineH(2,3,4,26);
        addLineH(2,2,16,26);
        addLineV(2,2,4,20);
        addLineV(2,2,10,20);
        addLineV(2,2,16,20);
        addLineV(2,3,28,14);
        addLineV(2,3,34,14);
        addLineV(2,3,40,14);
        addLineV(2,2,28,26);
        addLineV(2,2,34,26);
        addLineV(2,2,40,26);
        addObject(new Pine(),25,20);
        addObject(new Pine(),37,20);
        addObject(new Pine(),4,29);
        addObject(new Pine(),31,29);
        addObject(new SpiderWeb(),1,17);
        addObject(new SpiderWeb(),13,17);
        addObject(new SpiderWeb(),31,26);
        addObject(new SpiderWeb(),37,23);
        addObject(new SpiderWeb(),25,14);
        addObject(new SpiderWeb(),37,14);
        addObject(new SpiderWeb(),43,14);
        addObject(new SpiderWeb(),19,11);
        addObject(new SpiderWeb(),28,11);
        addObject(new SpiderWeb(),34,2);
        addObject(new Spider(),4,2);
        addObject(new Spider(),37,2);
        addObject(new Spider(),25,17);
        addObject(new Spider(),31,2);
        addObject(new Spider(),43,14);
        addObject(new Spider(),7,11);
        addObject(new Bird(),13,11);
        
        addObject(new InfoScreen(),46,15);
        addObject(new Lifes(), 46,11);
        addObject(new Score(), 46,17);
        addObject(new Lv(), 46,4);
        addObject(new Time(),46,25);
    }
    /**
     * Method that create all objects of level 9
     */
    public void dibujaLv9()
    {
        int i;
        currLv=9;

        setBackground("field_map.png");
        Greenfoot.start();//Re Starts the game on new Lv 
        removeObjects(getObjects(null)); // Clean all old objects from the last Lv
        addObject(new Lock(currLv), 22,2);
        addObject(new Female(),19,29); // Draw penguins on start position
        addObject(new Male(),25,29);  //Draw the Lv
        
        addLineH(2,4,1,26);
        addObject(new Pine(),16,26);
        addLineV(2,9,22,5);
        addObject(new Pine(),4,20);
        addLineH(2,4,10,20);
        addObject(new Pine(),16,14);
        addLineH(2,4,1,14);
        addObject(new Pine(),4,8);
        addLineH(2,4,10,8);
        addLineH(2,3,4,5);
        addObject(new Pine(),16,5);
        addLineV(2,4,28,20);
        addLineV(2,4,34,17);
        addLineV(2,4,40,20);
        addLineH(2,6,28,14);
        addLineV(2,3,28,5);
        addLineV(2,3,34,2);
        addLineV(2,3,40,5);
        addObject(new Spider(),4,2);
        addObject(new Spider(),37,2);
        addObject(new Spider(),25,17);
        addObject(new Spider(),31,2);
        addObject(new Spider(),43,20);
        addObject(new Bird(),27,4);
        addObject(new Bird(),8,20);
        for(i=0; i < 3; i++)
            addObject(new SpiderWeb(),25,5+i*3);
        addObject(new SpiderWeb(),1,2);
        addObject(new SpiderWeb(),13,2);
        addObject(new SpiderWeb(),10,11);
        addObject(new SpiderWeb(),19,11);
        addObject(new SpiderWeb(),13,14);
        addObject(new SpiderWeb(),4,17);
        addObject(new SpiderWeb(),7,23);
        addObject(new SpiderWeb(),10,20);
        addObject(new SpiderWeb(),19,26);
        addObject(new SpiderWeb(),13,29);
        addObject(new SpiderWeb(),25,23);
        addObject(new SpiderWeb(),28,17);
        addObject(new SpiderWeb(),31,26);
        addObject(new SpiderWeb(),37,17);
        addObject(new SpiderWeb(),43,23);
        addObject(new SpiderWeb(),31,8);
        addObject(new SpiderWeb(),37,2);
        addObject(new SpiderWeb(),43,5);
        
        addObject(new InfoScreen(),46,15);
        addObject(new Lifes(), 46,11);
        addObject(new Score(), 46,17);
        addObject(new Lv(), 46,4);
        addObject(new Time(),46,25);
    }    
    
}